@@ -14,8 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.exceptions import ClientError as Boto3ClientError
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.client import ClientMeta
 
 from mypy_boto3_serverlessrepo.paginator import (
     ListApplicationDependenciesPaginator,
@@ -50,26 +49,35 @@ else:
 __all__ = ("ServerlessApplicationRepositoryClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    BadRequestException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    ConflictException: Type[Boto3ClientError]
-    ForbiddenException: Type[Boto3ClientError]
-    InternalServerErrorException: Type[Boto3ClientError]
-    NotFoundException: Type[Boto3ClientError]
-    TooManyRequestsException: Type[Boto3ClientError]
+    BadRequestException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    ConflictException: Type[BotocoreClientError]
+    ForbiddenException: Type[BotocoreClientError]
+    InternalServerErrorException: Type[BotocoreClientError]
+    NotFoundException: Type[BotocoreClientError]
+    TooManyRequestsException: Type[BotocoreClientError]
 
 
 class ServerlessApplicationRepositoryClient:
     """
-    [ServerlessApplicationRepository.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client)
+    [ServerlessApplicationRepository.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.can_paginate)
         """
 
     def create_application(
@@ -91,7 +99,7 @@ class ServerlessApplicationRepositoryClient:
         TemplateUrl: str = None,
     ) -> CreateApplicationResponseTypeDef:
         """
-        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.create_application)
+        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.create_application)
         """
 
     def create_application_version(
@@ -104,7 +112,7 @@ class ServerlessApplicationRepositoryClient:
         TemplateUrl: str = None,
     ) -> CreateApplicationVersionResponseTypeDef:
         """
-        [Client.create_application_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.create_application_version)
+        [Client.create_application_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.create_application_version)
         """
 
     def create_cloud_formation_change_set(
@@ -124,19 +132,19 @@ class ServerlessApplicationRepositoryClient:
         TemplateId: str = None,
     ) -> CreateCloudFormationChangeSetResponseTypeDef:
         """
-        [Client.create_cloud_formation_change_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.create_cloud_formation_change_set)
+        [Client.create_cloud_formation_change_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.create_cloud_formation_change_set)
         """
 
     def create_cloud_formation_template(
         self, ApplicationId: str, SemanticVersion: str = None
     ) -> CreateCloudFormationTemplateResponseTypeDef:
         """
-        [Client.create_cloud_formation_template documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.create_cloud_formation_template)
+        [Client.create_cloud_formation_template documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.create_cloud_formation_template)
         """
 
     def delete_application(self, ApplicationId: str) -> None:
         """
-        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.delete_application)
+        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.delete_application)
         """
 
     def generate_presigned_url(
@@ -147,26 +155,26 @@ class ServerlessApplicationRepositoryClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.generate_presigned_url)
         """
 
     def get_application(
         self, ApplicationId: str, SemanticVersion: str = None
     ) -> GetApplicationResponseTypeDef:
         """
-        [Client.get_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.get_application)
+        [Client.get_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.get_application)
         """
 
     def get_application_policy(self, ApplicationId: str) -> GetApplicationPolicyResponseTypeDef:
         """
-        [Client.get_application_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.get_application_policy)
+        [Client.get_application_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.get_application_policy)
         """
 
     def get_cloud_formation_template(
         self, ApplicationId: str, TemplateId: str
     ) -> GetCloudFormationTemplateResponseTypeDef:
         """
-        [Client.get_cloud_formation_template documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.get_cloud_formation_template)
+        [Client.get_cloud_formation_template documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.get_cloud_formation_template)
         """
 
     def list_application_dependencies(
@@ -177,33 +185,33 @@ class ServerlessApplicationRepositoryClient:
         SemanticVersion: str = None,
     ) -> ListApplicationDependenciesResponseTypeDef:
         """
-        [Client.list_application_dependencies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.list_application_dependencies)
+        [Client.list_application_dependencies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.list_application_dependencies)
         """
 
     def list_application_versions(
         self, ApplicationId: str, MaxItems: int = None, NextToken: str = None
     ) -> ListApplicationVersionsResponseTypeDef:
         """
-        [Client.list_application_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.list_application_versions)
+        [Client.list_application_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.list_application_versions)
         """
 
     def list_applications(
         self, MaxItems: int = None, NextToken: str = None
     ) -> ListApplicationsResponseTypeDef:
         """
-        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.list_applications)
+        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.list_applications)
         """
 
     def put_application_policy(
         self, ApplicationId: str, Statements: List["ApplicationPolicyStatementTypeDef"]
     ) -> PutApplicationPolicyResponseTypeDef:
         """
-        [Client.put_application_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.put_application_policy)
+        [Client.put_application_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.put_application_policy)
         """
 
     def unshare_application(self, ApplicationId: str, OrganizationId: str) -> None:
         """
-        [Client.unshare_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.unshare_application)
+        [Client.unshare_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.unshare_application)
         """
 
     def update_application(
@@ -217,7 +225,7 @@ class ServerlessApplicationRepositoryClient:
         ReadmeUrl: str = None,
     ) -> UpdateApplicationResponseTypeDef:
         """
-        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.update_application)
+        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Client.update_application)
         """
 
     @overload
@@ -225,7 +233,7 @@ class ServerlessApplicationRepositoryClient:
         self, operation_name: Literal["list_application_dependencies"]
     ) -> ListApplicationDependenciesPaginator:
         """
-        [Paginator.ListApplicationDependencies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Paginator.ListApplicationDependencies)
+        [Paginator.ListApplicationDependencies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Paginator.ListApplicationDependencies)
         """
 
     @overload
@@ -233,7 +241,7 @@ class ServerlessApplicationRepositoryClient:
         self, operation_name: Literal["list_application_versions"]
     ) -> ListApplicationVersionsPaginator:
         """
-        [Paginator.ListApplicationVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Paginator.ListApplicationVersions)
+        [Paginator.ListApplicationVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Paginator.ListApplicationVersions)
         """
 
     @overload
@@ -241,8 +249,5 @@ class ServerlessApplicationRepositoryClient:
         self, operation_name: Literal["list_applications"]
     ) -> ListApplicationsPaginator:
         """
-        [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Paginator.ListApplications)
+        [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/serverlessrepo.html#ServerlessApplicationRepository.Paginator.ListApplications)
         """
-
-    def get_paginator(self, operation_name: str) -> Boto3Paginator:
-        pass
